from setuptools import setup

setup(
    name = 'distributions_saurav',
    version = '0.3',
    description = 'Gaussian and Binomial Distribution',
    packages = ['distributions_saurav'],
    author = 'Saurav Panchal',
    author_email = 'saurav.panchal.08@gmail.com',
    zip_safe = False
)